summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorranke <ranke@f247ebf9-aa24-0410-a698-f940e971ad2b>2009-04-18 00:14:22 +0000
committerranke <ranke@f247ebf9-aa24-0410-a698-f940e971ad2b>2009-04-18 00:14:22 +0000
commit45465a2ded6373a9fbae2419b502f9e3c049a740 (patch)
tree452db8c21539202ec97975a3eff2a8b480299ae9
parent6a325bb92a1eaa6ed8fc5e161437d31736ad4c72 (diff)
Update of the backporting scripts for 2.9.0 to etch
git-svn-id: svn+ssh://stiller/home/schatz/reps/r-backports@51 f247ebf9-aa24-0410-a698-f940e971ad2b
-rw-r--r--backport_all.sh16
-rw-r--r--publish_r-base.sh3
-rw-r--r--publish_the_rest.sh6
-rw-r--r--r-base/backport_r-base.sh18
4 files changed, 25 insertions, 18 deletions
diff --git a/publish_r-base.sh b/publish_r-base.sh
index f9c5582..33d7e1d 100644
--- a/publish_r-base.sh
+++ b/publish_r-base.sh
@@ -1,11 +1,10 @@
#!/bin/bash
-rsync -az \
+rsync -avz \
--include "build_log*" \
--include "build_errors*" \
--include "interdiff_to_debian_sid" \
--include "r-base_*etchcran*.diff.gz" \
--include "r-base_*etchcran*.dsc" \
- --include "*.orig.tar.gz" \
--include "*.deb" \
--exclude "*" \
r-base/ \
diff --git a/publish_the_rest.sh b/publish_the_rest.sh
index 9f015a4..5daf8c6 100644
--- a/publish_the_rest.sh
+++ b/publish_the_rest.sh
@@ -2,7 +2,7 @@
# Author: Johannes Ranke <jranke@uni-bremen.de>
-scp {boot,cluster,codetools,foreign,kernsmooth,lattice,mgcv,nlme,rpart,survival,vr,littler,rkward,rpy}/*.orig.tar.gz \
- chem:svn/website/www/ranke/r-cran/etch-cran
-scp {boot,cluster,codetools,foreign,kernsmooth,lattice,mgcv,nlme,rpart,survival,vr,littler,rkward,rpy}/*etchcran* \
+#scp {boot,cluster,codetools,foreign,kernsmooth,lattice,rmatrix,mgcv,nlme,rpart,survival,vr,rodbc,littler}/*.orig.tar.gz \
+ #chem:svn/website/www/ranke/r-cran/etch-cran
+scp -v {boot,cluster,codetools,foreign,kernsmooth,lattice,rmatrix,mgcv,nlme,rpart,survival,vr,rodbc,littler}/*etchcran* \
chem:svn/website/www/ranke/r-cran/etch-cran
diff --git a/r-base/backport_r-base.sh b/r-base/backport_r-base.sh
index dc89282..644edeb 100644
--- a/r-base/backport_r-base.sh
+++ b/r-base/backport_r-base.sh
@@ -12,7 +12,7 @@ export DEBEMAIL="Johannes Ranke <jranke@uni-bremen.de>"
#rm -rf r-base* r-base-core* r-mathlib*
-apt-get update
+#apt-get update
apt-get source -t unstable r-base
cd r-base-*
@@ -76,9 +76,23 @@ dch -a "debian/control: revert build dependence for tcl/tk to 8.4"
# 7. Openjdk is not in etch
-sed -i '/^Build-Depends/s/, openjdk-6-jdk \[!arm !hppa\]//' debian/control
+sed -i '/^Build-Depends/s/, openjdk-6-jdk \[!arm !hppa !kfreebsd-i386 !kfreebsd-amd64 !hurd-i386\]//' debian/control
dch -a "debian/control: Remove build dependence on openjdk"
+# 8. R 2.9.0 wants debhelper >= 7.0.0, which is not in etch
+
+sed -i '/^Build-Depends/s/debhelper (>= 7.0.0)/debhelper/' debian/control
+dch -a "debian/control: revert Build-Depends: to 'debhelper' since etch has a version < 7.0.0"
+sed -i 's/dh_prep/dh_clean/g' debian/rules
+dch -a "debian/rules: revert dh_prep calls to dh_clean calls since the latter is not present in this release's version of 'debhelper'"
+echo 5 > debian/compat
+dch -a "debian/compat: revert 'debhelper' compatibility level to 5"
+
+# 9. R 2.9.0 wants ucf >= 3.0 which is not available in etch (2.0020)
+
+sed -i 's/ucf (>= 3.0)/ucf/' debian/control
+dch -a "debian/control: revert Depends: of r-base-core to 'ucf' since the version in etch is < 3.0"
+
# Build package showing all messages and separating output to build and error logs
(dpkg-buildpackage -tc | tee ../build_log_r-base_i386) 3>&1 1>&2 2>&3 | tee ../build_errors_r-base_i386
if [ $? -ne 0 ]; then

Contact - Imprint
diff --git a/backport_all.sh b/backport_all.sh
index 319cc19..e7e5602 100644
--- a/backport_all.sh
+++ b/backport_all.sh
@@ -10,26 +10,20 @@ export DEBFULLNAME="Johannes Ranke"
text="Recompiled on etch for CRAN"
-for i in nlme; do
-#for i in boot cluster codetools foreign kernsmooth lattice mgcv nlme rodbc rpart survival vr littler rpy; do
+for i in rmatrix; do
+#for i in boot cluster codetools foreign kernsmooth lattice rmatrix mgcv nlme rodbc rpart survival vr littler; do
cd $i
rm -rf $i*
rm *.deb
apt-get source -t unstable $i
cd $i-*
- version=`dpkg-parsechangelog | grep ^Version | cut -f2 -d " "`~etchcran.2.8.1
+ version=`dpkg-parsechangelog | grep ^Version | cut -f2 -d " "`~etchcran.2.9.0
dch -b -v $version -D etch-cran $text
- sed -i '/^Build-Depends/s/r-base-dev (>= 2\..\..)/r-base-dev (>= 2.8.1-1~etchcran.0)/' debian/control
- sed -i '/^Build-Depends-Indep/s/r-base-dev (>= 2\..\..)/r-base-dev (>= 2.8.1-1~etchcran.0)/' debian/control
+ sed -i '/^Build-Depends/s/r-base-dev (>= 2\..\..)/r-base-dev (>= 2.9.0-1~etchcran.0)/' debian/control
+ sed -i '/^Build-Depends-Indep/s/r-base-dev (>= 2\..\..)/r-base-dev (>= 2.9.0-1~etchcran.0)/' debian/control
dch -a "debian/control: adapt build dependencies on r-base-dev to current backport"
- if [ ${i} == "rpy" ]
- then
- sed -i '/^Build-Depends/s/.*/&, lapack3-dev, python-minimal, python-central, python-dev, tetex-bin, texinfo/' debian/control
- dch -a "debian/control: add build dependencies on lapack3-dev, python-minimal, python-central, tetex-bin and texinfo"
- fi
-
fakeroot dpkg-buildpackage -sa
cd ../..
done